#---------------------------------------------------------------------------
#
#   SuPy GUI - Window - Cocoa
#
#---------------------------------------------------------------------------

import AppKit as AK
from g_window import GWindow
from container import PyNSView

ns_screen_height = AK.NSScreen.mainScreen().frame().size.height

#---------------------------------------------------------------------------

class Window(GWindow):
	#  _ns_window   PyNSWindow

	def __init__(self, style = 'standard', resizable = True, **kwds):
		flags = AK.NSTitledWindowMask | AK.NSClosableWindowMask
		if 'modal' not in style:
			flags |= AK.NSMiniaturizableWindowMask
		if resizable:
			flags |= AK.NSResizableWindowMask
		backing = AK.NSBackingStoreBuffered
		defer = True
		frame = ((0, 0), (100, 100))
		_ns_window = PyNSWindow.alloc().initWithContentRect_styleMask_backing_defer_(
			frame, flags, backing, defer)
		_ns_view = PyNSView.alloc().initWithFrame_(frame)
		_ns_window.setContentView_(_ns_view)
		_ns_window.py = self
		self._ns_window = _ns_window
		self._ns_style_mask = flags
		GWindow.__init__(self, _ns_view = _ns_view)
		self.pos = (200, 60)
		self.set(**kwds)
	
	def destroy(self):
		self.visible = False
		GWindow.destroy(self)
		self._ns_window = None
	
	def get_title(self):
		return self._ns_window.title()
	
	def set_title(self, x):
		self._ns_window.setTitle_(x)
	
	def get_visible(self):
		return self._ns_window.isVisible()
	
	def set_visible(self, v):
		if v:
			self._ns_window.orderFront_(None)
		else:
			self._ns_window.orderOut_(None)

	def get_bounds(self):
		ns_window = self._ns_window
		ns_frame = ns_window.frame()
		(l, y), (w, h) = ns_window.contentRectForFrameRect_styleMask_(
			ns_frame, self._ns_style_mask)
		b = ns_screen_height - y
		result = (l, b - h, l + w, b)
		return result
	
	def set_bounds(self, (l, t, r, b)):
		y = ns_screen_height - b
		ns_rect = ((l, y), (r - l, b - t))
		ns_window = self._ns_window
		ns_frame = ns_window.frameRectForContentRect_styleMask_(
			ns_rect, self._ns_style_mask)
		ns_window.setFrame_display_(ns_frame, False)
	
	def present(self):
		self.show()
		AK.NSApplication.sharedApplication().runModalForWindow_(self._ns_window)

#---------------------------------------------------------------------------

class PyNSWindow(AK.NSWindow):
	#  py   Window

	def windowShouldClose_(self, sender):
		AK.NSApplication.sharedApplication().abortModal()
		self.py.close()
		return False
