#---------------------------------------------------------------------------
#
#   SuPy GUI - Properties
#
#---------------------------------------------------------------------------

def overridable_property(name, doc = None):
	"""Creates a property which calls methods get_xxx and set_xxx of
	the underlying object to get and set the property value, so that
	the property's behaviour may be easily overridden by subclasses."""
	
	getter_name = intern('get_' + name)
	setter_name = intern('set_' + name)
	return property(
		lambda self: getattr(self, getter_name)(),
		lambda self, value: getattr(self, setter_name)(value),
		None,
		doc)

class Properties(object):
	"""Base class for objects whose properties can be
	set using keyword arguments to the constructor."""
	
	def __init__(self, **kwds):
		self.set(**kwds)
	
	def set(self, **kwds):
		for name, value in kwds.iteritems():
			#if not hasattr(self, name):
			#	raise TypeError("Unexpected keyword argument '%s'" % name)
			setattr(self, name, value)
